@@ -369,7 +369,7 @@ static PyObject *ExtGetSystemDir(
 {
     OLECHAR dir[MAX_PATH + 1];
     if (GetSystemDirectoryW(dir, sizeof(dir)))
-        return PyUnicode_FromUnicode(dir, wcslen(dir));
+        return PyUnicode_FromWideChar(dir, -1);
     PyErr_SetExcFromWindowsErr(PyExc_RuntimeError, GetLastError());
     return NULL;
 }
@@ -385,33 +385,17 @@ static PyObject *ExtGetWindowsDir(
 {
     OLECHAR dir[MAX_PATH + 1];
     if (GetWindowsDirectoryW(dir, sizeof(dir)))
-        return PyUnicode_FromUnicode(dir, wcslen(dir));
+        return PyUnicode_FromWideChar(dir, -1);
     PyErr_SetExcFromWindowsErr(PyExc_RuntimeError, GetLastError());
     return NULL;
 }
 #endif
 
 
-//-----------------------------------------------------------------------------
-// ExtSetOptimizeFlag()
-//   Set the optimize flag as needed.
-//-----------------------------------------------------------------------------
-static PyObject *ExtSetOptimizeFlag(
-    PyObject *self,                     // passthrough argument
-    PyObject *args)                     // arguments
-{
-    if (!PyArg_ParseTuple(args, "i", &Py_OptimizeFlag))
-        return NULL;
-    Py_INCREF(Py_None);
-    return Py_None;
-}
-
-
 //-----------------------------------------------------------------------------
 // Methods
 //-----------------------------------------------------------------------------
 static PyMethodDef g_ModuleMethods[] = {
-    { "SetOptimizeFlag", ExtSetOptimizeFlag, METH_VARARGS },
 #ifdef MS_WINDOWS
     { "BeginUpdateResource", ExtBeginUpdateResource, METH_VARARGS },
     { "UpdateResource", ExtUpdateResource, METH_VARARGS },
@@ -461,4 +445,3 @@ PyMODINIT_FUNC PyInit_util(void)
 #endif
     return module;
 }
-
